@@ -21,6 +21,7 @@ from typing import (
     Iterable,
     List,
     Optional,
+    TYPE_CHECKING,
     NamedTuple,
     Union,
 )
@@ -44,6 +45,8 @@ from .segment import Segment
 from .text import Text, TextType
 from .theme import Theme
 
+if TYPE_CHECKING:
+    from ._windows import WindowsConsoleFeatures
 
 WINDOWS = platform.system() == "Windows"
 
@@ -244,9 +247,22 @@ class RenderHook:
         return renderables
 
 
+_windows_console_features: Optional["WindowsConsoleFeatures"] = None
+
+
+def get_windows_console_features() -> "WindowsConsoleFeatures":  # pragma: no cover
+    global _windows_console_features
+    if _windows_console_features is not None:
+        return _windows_console_features
+    from ._windows import get_windows_console_features
+
+    _windows_console_features = get_windows_console_features()
+    return _windows_console_features
+
+
 def detect_legacy_windows() -> bool:
     """Detect legacy Windows."""
-    return "WINDIR" in os.environ and "WT_SESSION" not in os.environ
+    return WINDOWS and not get_windows_console_features().vt
 
 
 if detect_legacy_windows():  # pragma: no cover
@@ -277,6 +293,7 @@ class Console:
         log_time_format (str, optional): Log time format if ``log_time`` is enabled. Defaults to "[%X] ".
         highlighter (HighlighterType, optional): Default highlighter.
         legacy_windows (bool, optional): Enable legacy Windows mode, or ``None`` to auto detect. Defaults to ``None``.
+        safe_box (bool, optional): Restrict box options that don't render on legacy Windows.
     """
 
     def __init__(
@@ -301,6 +318,7 @@ class Console:
         log_time_format: str = "[%X]",
         highlighter: Optional["HighlighterType"] = ReprHighlighter(),
         legacy_windows: bool = None,
+        safe_box: bool = True,
     ):
         self.is_jupyter = force_jupyter or _is_jupyter()
         if self.is_jupyter:
@@ -336,6 +354,7 @@ class Console:
             show_time=log_time, show_path=log_path, time_format=log_time_format
         )
         self.highlighter: HighlighterType = highlighter or _null_highlighter
+        self.safe_box = safe_box
 
         self._record_buffer_lock = threading.RLock()
         self._thread_locals = ConsoleThreadLocals()
@@ -361,19 +380,26 @@ class Console:
 
     def _detect_color_system(self) -> Optional[ColorSystem]:
         """Detect color system from env vars."""
-        if not self.is_terminal:
-            return None
-        if self.legacy_windows:  # pragma: no cover
-            return ColorSystem.WINDOWS
-        if "WT_SESSION" in os.environ:
-            # Exception for Windows terminal
+        if self.is_jupyter:
             return ColorSystem.TRUECOLOR
-        color_term = os.environ.get("COLORTERM", "").strip().lower()
-        return (
-            ColorSystem.TRUECOLOR
-            if color_term in ("truecolor", "24bit")
-            else ColorSystem.EIGHT_BIT
-        )
+        if not self.is_terminal or "NO_COLOR" in os.environ:
+            return None
+        if WINDOWS:  # pragma: no cover
+            if self.legacy_windows:  # pragma: no cover
+                return ColorSystem.WINDOWS
+            windows_console_features = get_windows_console_features()
+            return (
+                ColorSystem.TRUECOLOR
+                if windows_console_features.truecolor
+                else ColorSystem.EIGHT_BIT
+            )
+        else:
+            color_term = os.environ.get("COLORTERM", "").strip().lower()
+            return (
+                ColorSystem.TRUECOLOR
+                if color_term in ("truecolor", "24bit")
+                else ColorSystem.EIGHT_BIT
+            )
 
     def _enter_buffer(self) -> None:
         """Enter in to a buffer context, and buffer all output."""
@@ -574,11 +600,7 @@ class Console:
             _rendered = Segment.apply_style(_rendered, style)
         lines = list(
             Segment.split_and_crop_lines(
-                _rendered,
-                render_options.max_width,
-                style=style,
-                include_new_lines=False,
-                pad=pad,
+                _rendered, render_options.max_width, include_new_lines=False, pad=pad
             )
         )
         return lines
@@ -687,16 +709,13 @@ class Console:
         text: List[Text] = []
         append_text = text.append
 
-        align = cast(
-            AlignValues, justify if justify in ("left", "center", "right") else "left"
-        )
+        append = _append
+        if justify in ("left", "center", "right"):
 
-        if align == "left":
-            append = _append
-        else:
+            def align_append(renderable: RenderableType) -> None:
+                _append(Align(renderable, cast(AlignValues, justify)))
 
-            def append(renderable: RenderableType) -> None:
-                _append(Align(renderable, align))
+            append = align_append
 
         _highlighter: HighlighterType = _null_highlighter
         if highlight or (highlight is None and self._highlight):
@@ -918,7 +937,7 @@ class Console:
         """Check if the buffer may be rendered."""
         with self._lock:
             if self._buffer_index == 0:
-                if self.is_jupyter:
+                if self.is_jupyter:  # pragma: no cover
                     from .jupyter import display
 
                     display(self._buffer)
