@@ -25,13 +25,17 @@ class Segment(NamedTuple):
         """Simplified repr."""
         return f"Segment({self.text!r}, {self.style!r}, {self.is_control!r})"
 
+    def __bool__(self) -> bool:
+        """Check if the segment contains text."""
+        return bool(self.text)
+
     @property
     def cell_length(self) -> int:
         """Get cell length of segment."""
         return 0 if self.is_control else cell_len(self.text)
 
     @classmethod
-    def control(self, text: str) -> "Segment":
+    def control(cls, text: str) -> "Segment":
         """Create a Segment with control codes.
 
         Args:
@@ -43,7 +47,7 @@ class Segment(NamedTuple):
         return Segment(text, is_control=True)
 
     @classmethod
-    def line(self) -> "Segment":
+    def line(cls) -> "Segment":
         """Make a new line segment."""
         return Segment("\n")
 
